@@ -38,6 +38,7 @@ void ags_app_action_util_save_as();
 void ags_app_action_util_meta_data();
 
 void ags_app_action_util_export();
+void ags_app_action_util_download();
 
 void ags_app_action_util_smf_import();
 void ags_app_action_util_smf_export();
@@ -81,6 +82,8 @@ void ags_app_action_util_edit_notation();
 void ags_app_action_util_edit_automation();
 void ags_app_action_util_edit_wave();
 void ags_app_action_util_edit_sheet();
+void ags_app_action_util_edit_meta();
+void ags_app_action_util_edit_tempo();
 
 G_END_DECLS
 
