@@ -203,12 +203,6 @@ void
 ags_fast_pitch_util_free(AgsFastPitchUtil *ptr)
 {
   g_return_if_fail(ptr != NULL);
-  
-  g_free(ptr->destination);
-
-  if(ptr->destination != ptr->source){
-    g_free(ptr->source);
-  }
 
   ags_stream_free(ptr->mix_buffer);
   ags_stream_free(ptr->im_mix_buffer);
@@ -241,7 +235,7 @@ ags_fast_pitch_util_get_destination(AgsFastPitchUtil *fast_pitch_util)
 /**
  * ags_fast_pitch_util_set_destination:
  * @fast_pitch_util: the #AgsFastPitchUtil-struct
- * @destination: the destination buffer
+ * @destination: (transfer none): the destination buffer
  *
  * Set @destination buffer of @fast_pitch_util.
  *
@@ -321,7 +315,7 @@ ags_fast_pitch_util_get_source(AgsFastPitchUtil *fast_pitch_util)
 /**
  * ags_fast_pitch_util_set_source:
  * @fast_pitch_util: the #AgsFastPitchUtil-struct
- * @source: the source buffer
+ * @source: (transfer none): the source buffer
  *
  * Set @source buffer of @fast_pitch_util.
  *
