@@ -69,45 +69,7 @@ ags_pitch_4x_alias_util_alloc()
   ptr = (AgsPitch4xAliasUtil *) g_new(AgsPitch4xAliasUtil,
 				       1);
 
-  ptr->source = NULL;
-  ptr->source_stride = 1;
-
-  ptr->destination = NULL;
-  ptr->destination_stride = 1;
-
-  ptr->alias_source_buffer = ags_stream_alloc(AGS_PITCH_4X_ALIAS_UTIL_DEFAULT_MAX_BUFFER_SIZE,
-					      AGS_SOUNDCARD_DEFAULT_FORMAT);
-
-  ptr->alias_source_max_buffer_length = AGS_PITCH_4X_ALIAS_UTIL_DEFAULT_MAX_BUFFER_SIZE;
-
-  ptr->alias_new_source_buffer = ags_stream_alloc(AGS_PITCH_4X_ALIAS_UTIL_DEFAULT_MAX_BUFFER_SIZE,
-						  AGS_SOUNDCARD_DEFAULT_FORMAT);
-
-  ptr->alias_new_source_max_buffer_length = AGS_PITCH_4X_ALIAS_UTIL_DEFAULT_MAX_BUFFER_SIZE;
-  
-  ptr->buffer_length = 0;
-  ptr->format = AGS_SOUNDCARD_DEFAULT_FORMAT;
-  ptr->samplerate = AGS_SOUNDCARD_DEFAULT_SAMPLERATE;
-
-  ptr->base_key = 0.0;
-  ptr->tuning = 0.0;
-
-  ptr->vibrato_enabled = TRUE;
-
-  ptr->vibrato_gain = 1.0;
-  ptr->vibrato_lfo_depth = 0.0;
-  ptr->vibrato_lfo_freq = 8.172;
-  ptr->vibrato_tuning = 0.0;
-
-  ptr->vibrato_lfo_frame_count = ptr->samplerate / ptr->vibrato_lfo_freq;
-  ptr->vibrato_lfo_offset = 0;
-
-  ptr->frame_count = 0;
-  ptr->offset = 0;
-
-  ptr->note_256th_mode = TRUE;
-
-  ptr->offset_256th = 0;
+  ptr[0] = AGS_PITCH_4X_ALIAS_UTIL_INITIALIZER;
   
   return(ptr);
 }
@@ -127,6 +89,8 @@ ags_pitch_4x_alias_util_copy(AgsPitch4xAliasUtil *ptr)
 {
   AgsPitch4xAliasUtil *new_ptr;
   
+  g_return_val_if_fail(ptr != NULL, NULL);
+  
   new_ptr = (AgsPitch4xAliasUtil *) g_new(AgsPitch4xAliasUtil,
 					   1);
   
@@ -161,9 +125,6 @@ ags_pitch_4x_alias_util_copy(AgsPitch4xAliasUtil *ptr)
   new_ptr->vibrato_lfo_freq = ptr->vibrato_lfo_freq;
   new_ptr->vibrato_tuning = ptr->vibrato_tuning;
 
-  new_ptr->vibrato_lfo_frame_count = ptr->vibrato_lfo_frame_count;
-  new_ptr->vibrato_lfo_offset = ptr->vibrato_lfo_offset;
-
   new_ptr->frame_count = ptr->frame_count;
   new_ptr->offset = ptr->offset;
 
@@ -185,15 +146,7 @@ ags_pitch_4x_alias_util_copy(AgsPitch4xAliasUtil *ptr)
 void
 ags_pitch_4x_alias_util_free(AgsPitch4xAliasUtil *ptr)
 {
-  if(ptr == NULL){
-    return;
-  }
-  
-  g_free(ptr->destination);
-
-  if(ptr->destination != ptr->source){
-    g_free(ptr->source);
-  }
+  g_return_if_fail(ptr != NULL);
 
   ags_stream_free(ptr->alias_source_buffer);
   ags_stream_free(ptr->alias_new_source_buffer);
@@ -224,7 +177,7 @@ ags_pitch_4x_alias_util_get_destination(AgsPitch4xAliasUtil *pitch_4x_alias_util
 /**
  * ags_pitch_4x_alias_util_set_destination:
  * @pitch_4x_alias_util: the #AgsPitch4xAliasUtil-struct
- * @destination: the destination buffer
+ * @destination: (transfer none): the destination buffer
  *
  * Set @destination buffer of @pitch_4x_alias_util.
  *
@@ -304,7 +257,7 @@ ags_pitch_4x_alias_util_get_source(AgsPitch4xAliasUtil *pitch_4x_alias_util)
 /**
  * ags_pitch_4x_alias_util_set_source:
  * @pitch_4x_alias_util: the #AgsPitch4xAliasUtil-struct
- * @source: the source buffer
+ * @source: (transfer none): the source buffer
  *
  * Set @source buffer of @pitch_4x_alias_util.
  *
@@ -774,46 +727,6 @@ ags_pitch_4x_alias_util_set_vibrato_tuning(AgsPitch4xAliasUtil *pitch_4x_alias_u
   pitch_4x_alias_util->vibrato_tuning = vibrato_tuning;
 }
 
-/**
- * ags_pitch_4x_alias_util_get_vibrato_lfo_offset:
- * @pitch_4x_alias_util: the #AgsPitch4xAliasUtil-struct
- * 
- * Get vibrato lfo_offset of @pitch_4x_alias_util.
- * 
- * Returns: the vibrato lfo_offset
- * 
- * Since: 6.15.0
- */
-guint
-ags_pitch_4x_alias_util_get_vibrato_lfo_offset(AgsPitch4xAliasUtil *pitch_4x_alias_util)
-{
-  if(pitch_4x_alias_util == NULL){
-    return(0);
-  }
-
-  return(pitch_4x_alias_util->vibrato_lfo_offset);
-}
-
-/**
- * ags_pitch_4x_alias_util_set_vibrato_lfo_offset:
- * @pitch_4x_alias_util: the #AgsPitch4xAliasUtil-struct
- * @vibrato_lfo_offset: the vibrato lfo_offset
- *
- * Set @vibrato_lfo_offset of @pitch_4x_alias_util.
- *
- * Since: 6.15.0
- */
-void
-ags_pitch_4x_alias_util_set_vibrato_lfo_offset(AgsPitch4xAliasUtil *pitch_4x_alias_util,
-						guint vibrato_lfo_offset)
-{
-  if(pitch_4x_alias_util == NULL){
-    return;
-  }
-
-  pitch_4x_alias_util->vibrato_lfo_offset = vibrato_lfo_offset;
-}
-
 /**
  * ags_pitch_4x_alias_util_get_frame_count:
  * @pitch_4x_alias_util: the #AgsPitch4xAliasUtil-struct
