@@ -240,8 +240,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* fixed length */
   fx_envelope_channel->fixed_length = g_object_new(AGS_TYPE_PORT,
 						   "plugin-name", ags_fx_envelope_channel_plugin_name,
-						   "specifier", ags_fx_envelope_channel_specifier[0],
-						   "control-port", ags_fx_envelope_channel_control_port[0],
+						   "specifier", "./fixed-length[0]",
+						   "control-port", "1/6",
 						   "port-value-is-pointer", FALSE,
 						   "port-value-type", G_TYPE_FLOAT,
 						   "port-value-size", sizeof(gfloat),
@@ -256,8 +256,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* attack */
   fx_envelope_channel->attack = g_object_new(AGS_TYPE_PORT,
 					     "plugin-name", ags_fx_envelope_channel_plugin_name,
-					     "specifier", ags_fx_envelope_channel_specifier[1],
-					     "control-port", ags_fx_envelope_channel_control_port[1],
+					     "specifier", "./attack[0]",
+					     "control-port", "2/6",
 					     "port-value-is-pointer", FALSE,
 					     "port-value-type", AGS_TYPE_COMPLEX,
 					     "port-value-size", sizeof(AgsComplex),
@@ -273,8 +273,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* decay */
   fx_envelope_channel->decay = g_object_new(AGS_TYPE_PORT,
 					    "plugin-name", ags_fx_envelope_channel_plugin_name,
-					    "specifier", ags_fx_envelope_channel_specifier[2],
-					    "control-port", ags_fx_envelope_channel_control_port[2],
+					    "specifier", "./decay[0]",
+					    "control-port", "3/6",
 					    "port-value-is-pointer", FALSE,
 					    "port-value-type", AGS_TYPE_COMPLEX,
 					    "port-value-size", sizeof(AgsComplex),
@@ -290,8 +290,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* sustain */
   fx_envelope_channel->sustain = g_object_new(AGS_TYPE_PORT,
 					      "plugin-name", ags_fx_envelope_channel_plugin_name,
-					      "specifier", ags_fx_envelope_channel_specifier[3],
-					      "control-port", ags_fx_envelope_channel_control_port[3],
+					      "specifier", "./sustain[0]",
+					      "control-port", "4/6",
 					      "port-value-is-pointer", FALSE,
 					      "port-value-type", AGS_TYPE_COMPLEX,
 					      "port-value-size", sizeof(AgsComplex),
@@ -307,8 +307,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* release */
   fx_envelope_channel->release = g_object_new(AGS_TYPE_PORT,
 					      "plugin-name", ags_fx_envelope_channel_plugin_name,
-					      "specifier", ags_fx_envelope_channel_specifier[4],
-					      "control-port", ags_fx_envelope_channel_control_port[4],
+					      "specifier", "./release[0]",
+					      "control-port", "5/6",
 					      "port-value-is-pointer", FALSE,
 					      "port-value-type", AGS_TYPE_COMPLEX,
 					      "port-value-size", sizeof(AgsComplex),
@@ -324,8 +324,8 @@ ags_fx_envelope_channel_init(AgsFxEnvelopeChannel *fx_envelope_channel)
   /* ratio */
   fx_envelope_channel->ratio = g_object_new(AGS_TYPE_PORT,
 					    "plugin-name", ags_fx_envelope_channel_plugin_name,
-					    "specifier", ags_fx_envelope_channel_specifier[5],
-					    "control-port", ags_fx_envelope_channel_control_port[5],
+					    "specifier", "./ratio[0]",
+					    "control-port", "6/6",
 					    "port-value-is-pointer", FALSE,
 					    "port-value-type", AGS_TYPE_COMPLEX,
 					    "port-value-size", sizeof(AgsComplex),
